﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;

namespace Shuffle
{
    /// <summary>
    /// Provides means to randomize the order of a list.
    /// Based on a Fisher-Yates shuffle.
    /// http://stackoverflow.com/a/1262619
    /// </summary>
    public static class ListShuffle
    {
        //fire up the RNG
        static readonly Random Random = new Random();
        
        /// <summary>
        /// Randomize the order of a list.
        /// </summary>
        /// <typeparam name="T">Type residing in list.</typeparam>
        /// <param name="list">List to be shuffled.</param>
        public static void Shuffle<T>(this IList<T> list)
        {
            int n = list.Count;//start at the 'end' of the list
            while (n > 1)
            {
                n--;//count our position down one
                int k = Random.Next(n + 1);//pick spot between the list 'start' and our position
                T value = list[k];//save the value from that spot
                list[k] = list[n];//save value from our position to that spot
                list[n] = value;//save the original value from the spot to our position
            }
        }
    }
}
